# mordred-web
mordred web interface

# install
```
pip install mordred-web
```

# execute
```
python -m mordred.web
```

# example

![top page](./img/upload.png)
![file viewer](./img/file.png)
![result page](./img/result.png)
